@@ -10,17 +10,19 @@
 use 5.014;
 use utf8;
 package App::SpreadRevolutionaryDate::Target::Twitter;
-$App::SpreadRevolutionaryDate::Target::Twitter::VERSION = '0.10';
+$App::SpreadRevolutionaryDate::Target::Twitter::VERSION = '0.11';
 # ABSTRACT: Target class for L<App::SpreadRevolutionaryDate> to handle spreading on Twitter.
 
 use Moose;
 with 'App::SpreadRevolutionaryDate::Target'
   => {worker => 'Net::Twitter::Lite::WithAPIv1_1'};
 
-use namespace::autoclean;
 use Net::Twitter::Lite::WithAPIv1_1;
 use Net::OAuth 0.25;
 
+use Locale::TextDomain 'App-SpreadRevolutionaryDate';
+use namespace::autoclean;
+
 has 'consumer_key' => (
     is  => 'ro',
     isa => 'Str',
@@ -67,12 +69,17 @@ sub spread {
   $test //= 0;
 
   if ($test) {
-    use Encode qw(encode);
+    $msg = __("Spread on Twitter: ") . $msg;
+
+    use open qw(:std :encoding(UTF-8));
     use IO::Handle;
     my $io = IO::Handle->new;
     $io->fdopen(fileno(STDOUT), "w");
-    my $utf8_msg = encode('UTF-8', $msg);
-    $io->say("Spread to Twitter: $utf8_msg");
+
+    use Encode qw(encode decode is_utf8);
+    $msg = encode('UTF-8', $msg) if is_utf8($msg);
+
+    $io->say($msg);
   } else {
     $self->obj->update($msg);
   }
@@ -101,7 +108,7 @@ App::SpreadRevolutionaryDate::Target::Twitter - Target class for L<App::SpreadRe
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 METHODS
 
@@ -117,7 +124,7 @@ Spreads a message to Twitter. Takes one mandatory argument: C<$msg> which should
 
 =over
 
-=item L<spread-revolutionary-date|https://metacpan.org/pod/distribution/App-SpreadRevolutionaryDate/bin/spread-revolutionary-date>
+=item L<spread-revolutionary-date>
 
 =item L<App::SpreadRevolutionaryDate>
 
@@ -135,6 +142,16 @@ Spreads a message to Twitter. Takes one mandatory argument: C<$msg> which should
 
 =item L<App::SpreadRevolutionaryDate::Target::MsgMaker::RevolutionaryDate>
 
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::RevolutionaryDate::Calendar>
+
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::RevolutionaryDate::Locale>
+
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::RevolutionaryDate::Locale::fr>
+
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::RevolutionaryDate::Locale::en>
+
+=item L<App::SpreadRevolutionaryDate::Target::MsgMaker::RevolutionaryDate::Locale::it>
+
 =item L<App::SpreadRevolutionaryDate::Target::MsgMaker::PromptUser>
 
 =back
